@@ -1,6 +1,8 @@
 import re
 
 import itty
+
+from restless.constants import OK, NO_CONTENT
 from restless.resources import Resource
 
 
@@ -16,8 +18,13 @@ class IttyResource(Resource):
     def is_debug(self):
         return self.debug
 
-    def build_response(self, data, status=200):
-        return itty.Response(data, status=status, content_type='application/json')
+    def build_response(self, data, status=OK):
+        if status == NO_CONTENT:
+            # Avoid crashing the client when it tries to parse nonexisting JSON.
+            content_type = 'text/plain'
+        else:
+            content_type = 'application/json'
+        return itty.Response(data, status=status, content_type=content_type)
 
     @classmethod
     def setup_urls(cls, rule_prefix):
@@ -30,7 +37,7 @@ class IttyResource(Resource):
         :returns: ``None``
         """
         list_url = "%s" % itty.add_slash(rule_prefix)
-        detail_url = "%s" % itty.add_slash(rule_prefix + "/(?P<pk>\d+)")
+        detail_url = "%s" % itty.add_slash(rule_prefix + "/(?P<pk>[\w-]+)")
 
         list_re = re.compile("^%s$" % list_url)
         detail_re = re.compile("^%s$" % detail_url)
