@@ -1,6 +1,7 @@
 import datetime
 import decimal
 import traceback
+import uuid
 
 try:
     import json
@@ -18,12 +19,13 @@ class MoreTypesJSONEncoder(json.JSONEncoder):
         * ``datetime.date``
         * ``datetime.time``
         * ``decimal.Decimal``
+        * ``uuid.UUID``
 
     """
     def default(self, data):
         if isinstance(data, (datetime.datetime, datetime.date, datetime.time)):
             return data.isoformat()
-        elif isinstance(data, decimal.Decimal):
+        elif isinstance(data, decimal.Decimal) or isinstance(data, uuid.UUID):
             return str(data)
         else:
             return super(MoreTypesJSONEncoder, self).default(data)
